@@ -15,7 +15,6 @@ use std::io::{Read, Write};
 
 use bitcoin::consensus::deserialize;
 use bitcoin::{hashes, secp256k1, Script};
-use wallet::scripts::PubkeyScript;
 
 use super::{strategies, Strategy};
 use crate::{Error, LightningDecode, LightningEncode};
@@ -76,26 +75,18 @@ impl Strategy for secp256k1::SecretKey {
     type Strategy = strategies::AsStrict;
 }
 
-impl Strategy for secp256k1::Signature {
+impl Strategy for secp256k1::ecdsa::Signature {
     type Strategy = strategies::AsStrict;
 }
 
-impl Strategy for wallet::hlc::HashLock {
+impl Strategy for wallet::hlc::hlc::HashLock {
     type Strategy = strategies::AsStrict;
 }
 
-impl Strategy for wallet::hlc::HashPreimage {
+impl Strategy for wallet::hlc::hlc::HashPreimage {
     type Strategy = strategies::AsStrict;
 }
 
-impl Strategy for lnpbp::chain::AssetId {
-    type Strategy = strategies::AsStrict;
-}
-
-impl Strategy for lnpbp::bech32::Blob {
-    type Strategy = strategies::AsWrapped;
-}
-
 impl LightningEncode for Script {
     #[inline]
     fn lightning_encode<E: Write>(&self, e: E) -> Result<usize, Error> {
@@ -105,11 +96,7 @@ impl LightningEncode for Script {
 
 impl LightningDecode for Script {
     fn lightning_decode<D: Read>(d: D) -> Result<Self, Error> {
-        Ok(deserialize(&Vec::<u8>::lightning_decode(d)?)
-            .map_err(|err| Error::DataIntegrityError(err.to_string()))?)
+        deserialize(&Vec::<u8>::lightning_decode(d)?)
+            .map_err(|err| Error::DataIntegrityError(err.to_string()))
     }
 }
-
-impl Strategy for PubkeyScript {
-    type Strategy = strategies::AsWrapped;
-}
